<?php
namespace Neuron\Person\Attribute;

use Neuron\Generic\Entity\Map;
use Neuron\Generic\Result;

class Type extends \Neuron\Generic\Entity\Mapper {

    protected $_storage;

    public function __construct(Type\Storage\Skeleton $storage) {

        /* simpan storage */
        $this->_storage = $storage;

        /* map properti ke tabel */
        parent::__construct(
            array(),
            array(
                new Map("attr_type_id"),
                new Map("attr_code"),
                new Map("attr_name"),
            ),
            parent::CASE_INSENSITIVE
        );
    }

    public function load($id, $mode = Type\Storage::LOADBY_ID) {

        /* query */
        if ($data = $this->_storage->load($id, $mode)) {
            
            $this->push($data);

            /* berhasil */
            return $this->id;
        }

        /* default gagal */
        return false;
    }

    public function save($update = false) {

        /* simpan */
        if ($id = $this->_storage->save($this, $update)) {

            /* set id */
            $this->attr_type_id = $id;
            return $id;
        }

        /* return hasil */
        return false;
    }

    public function saveEx($data){
        $result     = new Result();
        $update     = false; 
        if($this->attr_type_id){
            $update     = true;
        }

        $this->push($data);
        if(!$this->save($update)){
            $result->code   = 2;
            $result->info   = "Failed saving data";
            return $result;
        }
        $result->data   = $this->pull();
        return $result;
    }
	
	public function delete($id){
        $result = new Result();
		try {
			/* loaded? */
		
			if ($this->_storage->remove($id)) {

				$result->info = 'Success deleting attribute type';
			} else {

				//gagal
				$result->code = 51;
				$result->info = 'Failed deleting attribute type';

			}
				
			return $result;
		} catch (\Exception $ex) {
			error_log('Error at ' . $ex->getFile() . ' line ' . $ex->getLine() . ': ' . $ex->getMessage());
			$result->code = 500;
			$result->info = $ex->getMessage();
			return $result;
		}
    }
}
