<?php
namespace Neuron\Person\Controller\Api;

use Neuron\Generic\Result;
use Neuron\Application\Framework\Entity;
use Neuron\Person\Families;
use Neuron\Person\Family as FamilyModel;

class Family extends \Neuron\Person\Controller {

    const CODE_FIELD_REQUIRED = 410;
    const CODE_SESSION_EXPIRED = 411;

    public function loadAction(){
        $result = new Result();
        $guid   = $this->getREST()->getGuid();
        if ($guid == "" || empty($guid)) {
            $result->code = self::CODE_FIELD_REQUIRED;
            $result->info = 'token is null';
            return $this->getREST()->getResponse($result);
        }

        $entity = Entity::get($this, $guid);
        $user = $entity->user();
        if (!$user->id) {
            $result->code = self::CODE_SESSION_EXPIRED;
            $result->info = 'Session Expired';
            return $this->getREST()->getResponse($result);
        }

        $userPerson = $this->getUserPerson($user);
        $person = $userPerson['person'];
        $personId = $person['ref_id'];


        try {
            $families = new Families(FamilyModel\Storage::factory($this->getDb(),$this->getConfig()));
            $dataFamilies = $families->load(
                array('person_id' => $personId)
            );
            $result->data = array(
                'rows' => $dataFamilies['data'],
                'countTotal' => $dataFamilies['recordsTotal']
            );

        } catch (\Exception $th) {
            $result->code = 500;
            $result->info = "failed loading families";
        }
		
		$requestPost = array(
			'guid' => $guid,
			'code' => '',
			'info' => '',
			'data' => ''
		); 
		
		$responseResult = array(
			'guid' => $result->guid,
			'code' => $result->code,
			'info' => $result->info,
			'data' => $result->data
		); 
		
		$logparam['subject'] = 'API PERSON LOAD FAMILY';
		$logparam['identity'] = $personId ? $personId : '';
		$logparam['user'] = $person ? $person : '';
		$logparam['description'] = 'Log proses api person load family';
		$logparam['request'] = json_encode($requestPost);
		$logparam['response'] = json_encode($responseResult);
		
		$this->writeLogAction($logparam);
		
        return $this->getREST()->getResponse($result);

    }

}
