<?php

namespace Neuron\Person\Detail\Storage;

use Neuron\Person\Detail\Storage;

class Mysql extends \Neuron\Db\Storage implements Skeleton {

	public function listdata($perId) {
		$select = $this->select()
						->from(array('det' => $this->_tables['person_detail']))
						->where(array('det.detail_id' => $perId));
		
		$select->order(array('det.year_graduated DESC'));
										
		//echo str_replace('"','',$select->getSqlString())."<br />";                
		return $this->fetchAll($select);
	}

	public function load($id, $mode = Storage::LOADBY_ID) {
		$select = $this->select()
						->from($this->_tables['person_detail']);
		switch ($mode){
			case Storage::LOADBY_ID :
				$select->where($this->__(array('detail_id' => $id)));
				break;
			case Storage::LOADBY_PERSON :
				$select->where($this->__(array('person_id' => $id)));
				break;
			
		}
		return $this->fetchRow($select);
	}
	
	public function save(\Neuron\Person\Detail $detail, $update = false) {
		if ($update) {
			$update = $this->update()
				->table($this->_tables['person_detail'])
				->set($this->__($detail->pull()))
				->where($this->__(array('detail_id' => $detail->detail_id)));
			// echo str_replace('"','',$update->getSqlString())."<br />";  die();         
			if ($this->execute($update)) {
					return $detail->detail_id;
			}
		} else {
			$dataDetail = $this->__($detail->pull());
			$dataDetail['detail_id'] = null;
			$insert = $this->insert()
				->into($this->_tables['person_detail'])
				->values($dataDetail);
			$save = $this->execute($insert);
			if ($save) {
				$detail->detail_id = $save;
				return $detail->detail_id;
			}
		}

		return false;
	}

	public function remove($perDetId) {
		$delete = $this->delete()
						->from($this->_tables['person_detail'])
						->where(array('detail_id' => $perDetId));
								
		return $this->execute($delete);
	}

    public function loadList($ids, $mode = Storage::LIST_ALL, $params = null){
        /* base select */
        $select = $this->select()
            ->from(['a' => $this->_tables['person_detail']]);
        /* loadby page */
        if ($mode === Storage::LISTBY_PAGE) {
            /* get pager */
            $pager = Pager::sanitize($params);
            $select->limit($pager->getLimit())->offset($pager->getOffset())->cache(0);

            /* has keyword? */
            if (!empty($ids)) {
                $select->where->nest()
                    ->like($this->_('about', 'a.'), '%' . trim($ids) . '%')
                    ->or
                    ->like($this->_('termination_reason', 'a.'), '%' . trim($ids) . '%')
                    ->unnest();
            }
        } else {
            $pager = new \Neuron\Db\Storage\Pager(1, 999999);

            switch ($mode) {
                case Storage::LISTBY_PERSONID:
                    $select->where([$this->_('person_id', 'a.') => $ids]);
                    break;
            }
        }

        try {
            // echo @str_replace('"','', $select->getSqlString());die();
            $rows = $this->fetchAll($select);
            $result = new \stdClass();
            $result->list = $rows;
            $result->pager = $pager;
            $total = isset($rows->total) ? $rows->total : 0;
            $result->countTotal = $total;
            return $result;
        } catch (\Throwable $ex) {
            error_log('Error at ' . $ex->getFile() . ' line ' . $ex->getLine() . ': ' . $ex->getMessage());
            return false;
        }
    }

}